@@ -6,6 +6,7 @@ test_that("Comparing equal strings works",{
 
 test_that("Deletions works",{
    expect_equal(damerauLevenshteinDistance(130, 1340), 1)
+   expect_equal(damerauLevenshteinDistance(1340, 130), 1)
 })
 
 test_that("Insertion works",{
@@ -20,6 +21,11 @@ test_that("Transposition",{
    expect_equal(damerauLevenshteinDistance(1340, 1430), 1)
 })
 
-test_that("Transposition",{
+test_that("Transposition + insertion works",{
    expect_equal(damerauLevenshteinDistance(1340, 14300), 2)
+})
+
+test_that("simple sign switch works",{
+   expect_equal(damerauLevenshteinDistance(-10, 10), 1)
+   expect_equal(damerauLevenshteinDistance(-1, 10), 2)
 })
\ No newline at end of file
